"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _resolveDebugLevels = _interopRequireDefault(require("resolve-debug-levels"));

var _resolveReadmodelBase = require("resolve-readmodel-base");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const log = (0, _resolveDebugLevels.default)('resolve:resolve-readmodel-postgresql-serverless:begin-event');

const beginEvent = async (pool, readModelName, xaTransactionId) => {
  try {
    pool.xaTransactionId = xaTransactionId;
    const savepointId = pool.generateGuid(readModelName, xaTransactionId);
    const insideEventId = `resolve.${pool.generateGuid(readModelName, xaTransactionId, 'insideEventId')}`;
    await pool.rdsDataService.executeStatement({
      resourceArn: pool.dbClusterOrInstanceArn,
      secretArn: pool.awsSecretStoreArn,
      database: 'postgres',
      continueAfterTimeout: false,
      includeResultMetadata: false,
      transactionId: xaTransactionId,
      sql: `
        SAVEPOINT ${savepointId};
        SET LOCAL ${insideEventId} = 1;
      `
    });
    log.verbose('Begin event to postgresql database succeed');

    if (!pool.eventCounters.has(xaTransactionId)) {
      pool.eventCounters.set(xaTransactionId, 0);
    }

    pool.readModelName = readModelName;
  } catch (error) {
    log.verbose('Begin event to postgresql database failed', error);

    if (error != null && /Transaction .*? Is Not Found/i.test(error.message)) {
      throw _resolveReadmodelBase.OMIT_BATCH;
    }

    throw error;
  }
};

var _default = beginEvent;
exports.default = _default;
//# sourceMappingURL=begin-event.js.map